
import random
from time import sleep
from math import floor
import json

import network
import socket
from time import sleep
#from picozero import pico_temp_sensor, pico_led
import machine

from urequest import request
from pico_epaper_75 import EPD_7in5_B

print("Starting up")

def show_error():
    epd.imageblack.text("ERROR PROCESSING", random.randint(0, 700), random.randint(0, 450), 0x00)


with open("config.json", "r") as fh:
    config = json.load(fh)

server_url = None

print("Starting Wifi")
connected = False
while not connected:
    for net_config in config:
        # Connect to wifi
        wlan = network.WLAN(network.STA_IF)
        wlan.active(True)
        print("Attempting to connect to:", net_config.get("wifi_ssid"))
        wlan.connect(net_config.get("wifi_ssid"), net_config.get("wifi_password"))

        connect_timeout = 5
        while wlan.isconnected() == False and connect_timeout > 0:
            print('Waiting for connection...')
            sleep(1)
            connect_timeout -= 1

        # If connected break from setup
        if wlan.isconnected():
            print("Connected to Wifi")
            server_url = net_config.get("server_url")
            print("Using server URL:", server_url)
            connected = True
            break
        else:
            # Disconnect from current network
            wlan.disconnect()
    else:
        print("Could not find WIFI network")

print("Initialising display")
epd = EPD_7in5_B()
epd.Clear()
epd.sleep()
print("Display initialisation complete")

while True:
    try:

        epd.imageblack.fill(0xff)
        epd.imagered.fill(0x00)

        print("Getting display ID")
        id_request = request("GET", f"{server_url}/generate")
        screen_id = id_request.json().get("id")

        for h in range(epd.height):

            print(f"Making request to server for line {h}")
            res = request("GET", f"{server_url}/screen/{screen_id}/{h}")
            print("Request complete")

            screen_data = bytes(res.content)

            for w in range(epd.width):
                pixel_itx = w
                bytes_index = floor(pixel_itx / 4)
                byte_index = pixel_itx % 4
                pixel_data = int((screen_data[bytes_index] & (3 << (byte_index * 2))) >> (byte_index * 2))
                if pixel_data == 1:
                    epd.imageblack.pixel(w, h, 0x00)
                elif pixel_data == 2:
                    epd.imagered.pixel(w, h, 0xff)
    except Exception as exc:
        show_error()
        print(str(exc))

    print("initialising display")
    epd.init()
    print("Updating display")
    epd.display()
    print("sleeping display")
    epd.sleep()
    print("sleeping for 4 minutes")
    sleep(240)

