
from PIL import Image
import numpy as np
import cv2

from stats_lib.display.base_display import BaseDisplay


class EnergyFlowDiagramDisplay(BaseDisplay):
    """Energy flow diagram display"""

    def draw(self):
        """Draw"""

        # Draw images
        for image_name, x, y, resize_x, resize_y in [
                ("house", 350, 200, 100, 100),
                ("electricity_pilon", 600, 370, 50, 100),
                ("solar_panel", 350, 50, 100, 50),
                ("battery", 100, 400, 100, 50)]:
            try:
                image_path = f"stats_lib/images/{image_name}.png"
                if image_path:
                    image = Image.open(image_path)
                    image = image.resize((resize_x, resize_y))
                    self._framebuffer._image.paste(image.copy(), (x, y))
            except:
                print("Failed to open/put weather image into display")

        usage = self._data_source.get_latest_value("usage_consumption_w", default=0.0)
        battery_power = self._data_source.get_latest_value("battery_power_w", default=0.0)
        grid_power = self._data_source.get_latest_value("grid_power_w", default=0.0)
        solar = self._data_source.get_latest_value("solar_power_w", default=0.0)

        # Solar power generated goes to provide usage first
        pv_to_home = min(usage, solar)
        to_battery = max(0, 0 - battery_power)
        from_battery = max(0, battery_power)
        pv_to_battery = min(to_battery, max(0, solar - pv_to_home))
        grid_to_battery = max(0, to_battery - pv_to_battery)
        battery_to_home = min(max(0, usage - pv_to_home), from_battery)
        pv_to_grid = max(0, (solar - pv_to_home) - pv_to_battery)
        grid_to_home = (usage - pv_to_home) - battery_to_home


        for start_x, start_y, end_x, end_y, text_x, text_y, val in [
            # Grid to home
            (580, 390, 460, 290, -70, 0, grid_to_home),
            # Battery to grid
            (220, 415, 580, 415, 0, 0, (0)), ##  Check if valid
            # Grid to battery
            (580, 415, 220, 415, 0, 0, grid_to_battery),
            # Battery to home
            (200, 395, 350, 290, 10, 0, battery_to_home),
            # PV to battery
            (350, 100, 170, 370, -100, -20, pv_to_battery),
            # PV to home
            (397, 110, 397, 190, 5, 0, pv_to_home),
            # PV to grid
            (450, 100, 610, 370, 30, -20, pv_to_grid),
        ]:
            val = int(val)
            if val:
                # Convert framebuffer image to NP array
                na = np.array(self._framebuffer._image)
                # Add arrow lined
                na = cv2.arrowedLine(na, (start_x, start_y), (end_x, end_y),
                                     (0, 0, 0), 2)
                # Paste NP array back to framebuffer
                self._framebuffer._image.paste(Image.fromarray(na).copy())

                if val > 1000:
                    text = f"{round(val / 1000, 2)}KW"
                else:
                    text = f"{int(val)}W"
                # Add text label to framebuffer
                self._framebuffer.text(
                    text,
                    (int((start_x + end_x ) / 2) + text_x,
                     int((start_y + end_y ) / 2) + text_y),
                     font_size=25
                )

        # Battery charge percentage
        self._framebuffer.text(f"{int(self._data_source.get_latest_value('battery_charge_perc'))}%", (110, 405))
