
from PIL import Image


from stats_lib.display.base_display import BaseDisplay


class WeatherToday(BaseDisplay):
    """Weather display"""

    SHOW_IN_ROTATION = False

    IMAGE_LOOKUP = {
        "cloud": [1003, 1006],
        "drizzle": [1150, 1153],
        "hail": [1069, 1072, 1114, 1117, 1198, 1201, 1204, 1207, 1249, 1252, 1255, 1258, 1261, 1264],
        "heavy_rain": [1186, 1189, 1192, 1195, 1243, 1246],
        "ice": [1147, 1168, 1171],
        "light_rain": [1063, 1180, 1183, 1240],
        "lightning": [1087, 1273, 1276, 1279, 1282],
        "overcast": [1009, 1030, 1135],
        "snow": [1066, 1210, 1213, 1216, 1219, 1222, 1225, 1237],
        "sun": [1000]
    }

    def draw(self):
        """Draw"""
        # Show default items
        super().draw()

        self._framebuffer.text(f"Weather", (160, 80), font_size=60)

        temperature = self._data_source.get_latest_value('weather_api_temp_c')
        self._framebuffer.text(f"Temperature: {round(temperature, 2)}°C", (20, 160),
                               color=self._framebuffer.RED if (temperature > 25 or temperature < 3) else self._framebuffer.BLACK)
        self._framebuffer.text(f"Wind Speed: {round(self._data_source.get_latest_value('weather_api_wind_mph'), 2)}mph", (20, 200))
        self._framebuffer.text(f"Gust Speed: {round(self._data_source.get_latest_value('weather_api_gust_mpg'), 2)}mph", (20, 240))
        self._framebuffer.text(f"Humidity: {round(self._data_source.get_latest_value('weather_api_humidity'), 2)}%", (20, 280))
        self._framebuffer.text(f"UV: {round(self._data_source.get_latest_value('weather_api_uv'), 2)}", (20, 320))
        self._framebuffer.text(f"Feels like: {round(self._data_source.get_latest_value('weather_api_feelslike_c'), 2)}°C", (20, 360))

        try:
            image_path = self._get_image_from_weather()
            if image_path:
                image = Image.open(image_path)
                self._framebuffer._image.paste(image.copy(), (500, 160))
        except:
            print("Failed to open/put weather image into display")

    def _get_image_from_weather(self):
        """Return image from type of weather"""
        condition_code = self._data_source.get_latest_value('weather_api_weather_condition_code')
        for image_name, conditions in self.IMAGE_LOOKUP.items():
            if condition_code in conditions:
                image = image_name
                break
        else:
            return None

        # If wind is high and other condition is unimportant,
        # override with wind
        if (image in ["sun", "cloud"] and (
                    self._data_source.get_latest_value('weather_api_wind_mph') > 20 or
                    self._data_source.get_latest_value('weather_api_gust_mpg') > 30
                )):
            image = "wind"

        return f"stats_lib/images/{image}.png"