
"""
API
Type: News
Provider: World News API
Provider Link: https://worldnewsapi.com
Status: In Development
"""

from enum import Enum
import os

import requests

from stats_lib.utils import print_debug
from stats_lib.data_point import DataPoint


class NewsApi:

    API_KEY = os.environ.get("NEWS_API_KEY")
    SOURCES = os.environ.get("NEWS_API_SOURCES", "bbc-news")

    def _make_api_call(self, endpoint, params=None):
        """Make API call"""
        if not self.API_KEY:
            print(f"No API key present for {self.__class__.__name__}")
            return None

        if params is None:
            params = {}

        url = f"https://newsapi.org/v2/{endpoint}"

        params['apiKey'] = self.API_KEY

        print_debug("Calling", url, "with", params)

        try:
            res = requests.get(
                url,
                headers={
                    "Accept": "application/json",
                    "Content-Type": "application/json"
                },
                params=params,
                timeout=30
            )
        except requests.exceptions.ConnectTimeout:
            return None

        if res.status_code == 200:
            json_response = res.json()
            print_debug("Got response", json_response)
            return json_response
        else:
            print(f"Error response from {self.__class__.__name__}: ", res.status_code, res.content)
            return None

    def get_news_articles(self):
        """Obtain latest news articles"""
        data = self._make_api_call(
            "top-headlines",
            params={
                "sources": self.SOURCES
            }
        )
        return data.get("articles")
