"""
API
Type: Weather data
Provider: Open Weather Map
Provider Link: https://openweathermap.org
Status: Incomplete/deprecated
"""


import os

import requests

from stats_lib.utils import print_debug



class OpenWeatherMap:

    API_KEY = os.environ.get("OPEN_WEATHER_MAP_API_KEY")
    LAT = os.environ.get("LOCATION_LAT")
    LON = os.environ.get("LOCATION_LON")

    def _make_api_call(self, endpoint, params=None):
        """Make API call"""
        if not self.API_KEY:
            print("No API key present for OpenWeatherMap")
            return None

        if params is None:
            params = {}

        url = f"https://api.openweathermap.org/data/2.5/{endpoint}"

        params['appid'] = self.API_KEY

        print_debug("Calling", url, "with", params)

        try:
            res = requests.get(
                url,
                headers={
                    "Accept": "application/json",
                    "Content-Type": "application/json"
                },
                params=params,
                timeout=30
            )
        except requests.exceptions.ConnectTimeout:
            return None

        if res.status_code == 200:
            json_response = res.json()
            print_debug("Got response", json_response)
            return json_response
        else:
            print('Error response from GivEnergy: ', res.status_code, res.content)
            return None

    def get_current_weather(self):
        """Get current weather conditions"""
        lat = self.LAT
        lon = self.LON
        if not lat or not lon:
            return

        res = self._make_api_call("weather", {"lat": lat, "lon": lon})
        print(res)
