"""
API
Type: News
Provider: World News API
Provider Link: https://worldnewsapi.com
Status: In Development
"""

from enum import Enum
import os

import requests

from stats_lib.utils import print_debug
from stats_lib.data_point import DataPoint


class WorldNewsApi:

    API_KEY = os.environ.get('WORLD_NEWS_API_KEY')
    SENTIMENT_MIN = os.environ.get('WORLD_NEWS_SENTIMENT_MIN', '0.0')
    SENTIMENT_MAX = os.environ.get('WORLD_NEWS_SENTIMENT_MAX', '1.0')
    NEWS_SOURCES = os.environ.get('WORLD_NEWS_SOURCES', 'https://www.bbc.co.uk')
    COUNTRY_CODE = os.environ.get('WORLD_NEWS_COUNTRY_CODE', 'uk')

    def _make_api_call(self, endpoint, params=None):
        """Make API call"""
        if not self.API_KEY:
            print(f"No API key present for {self.__class__.__name__}")
            return None

        if params is None:
            params = {}

        url = f"https://api.worldnewsapi.com/{endpoint}"

        params['api-key'] = self.API_KEY

        print_debug("Calling", url, "with", params)

        try:
            res = requests.get(
                url,
                headers={
                    "Accept": "application/json",
                    "Content-Type": "application/json"
                },
                params=params,
                timeout=30
            )
        except requests.exceptions.ConnectTimeout:
            return None

        if res.status_code == 200:
            json_response = res.json()
            print_debug("Got response", json_response)
            return json_response
        else:
            print(f"Error response from {self.__class__.__name__}: ", res.status_code, res.content)
            return None

    def get_news_articles(self):
        """Obtain latest news articles"""
        data = self._make_api_call(
            "search-news",
            params={
                "min-sentiment": self.SENTIMENT_MIN,
                "max-sentiment": self.SENTIMENT_MAX,
                "news-sources": self.NEWS_SOURCES,
                "source-countries": self.COUNTRY_CODE
            }
        )
        print(data)
        return data.get("news")
